@@ -1,3 +1,7 @@
+from functools import partial
+
+from jax import jit
+
 import jax.numpy as jnp
 
 
@@ -23,6 +27,7 @@ class Error:
     def errors(gstate):
         raise NotImplementedError
 
+    @partial(jit, static_argnums=0)
     def __call__(self, eqstate):
         """
         Return the current value of the error term.
